%% employment as a function of SD and quarantine
function [e, eSD]=GSEIR_EMPfun(t,x,p,ss)
% GSEIR_EMPfun: working population is W=S+E+(1-eI1)*I1e+(1-eI2)*I2+R
% effective employment with SD is EMP=aS*W
% A.Hornstein 4/11/2020
% Added tracing of exposed
% -------------------------------------------------------------------------
nS=length(ss);
eSD=zeros(length(t),1);

% employment effects of social distancing
% Assume that a 45 percent base reduction of the transmission rate due to
% SD measures reduces employment by 25 percent relative to base.
% da   (ransmission rate) ranges from      0.55  to 1 
% dpsi (contact rate)     ranges from sqrt(0.55) to 1 with corresponding EMP from 0.75 to 1
% Make the employment effect proportional to the contact rate psi, that is, the
% square root of the transmission rate
da   =p.a./p.aD;
dpsi =sqrt(da);
dpsi0=sqrt(0.55);
SDemp=0.75+0.25*(dpsi-dpsi0)/(1-dpsi0);

notQ=eSD;
for i=1:nS-1
    eSD=eSD + SDemp(i)*(ss(i)<=t).*(t<ss(i+1));
    notQ=notQ + ( (1-p.eI1(i))*(x(:,4)+x(:,5)) + (1-p.eI2(i))*x(:,6) ).*(ss(i)<=t).*(t<ss(i+1));
end
e  =sum(x(:,[1,2,3,9]),2) + notQ;
eSD=eSD.*e;
end
