% GSEIR_MCsim_plot: Plot impact of different policies in UK or US accounting
% for parameter uncertainty.
%
% A.Hornstein, 4/4/2020
% -------------------------------------------------------------------------
clear all;
KCclust=0;
matdir='GSEIRmat\';
figdir='GSEIRfig\';
if KCclust==1
    matdir='GSEImat/';
    figdir='GSEIRfig/';
end
% Update path to access procs_dir
utilities_dir = 'utilities';
pathO= path;
pathN= path(utilities_dir,pathO);

fid=1;
% pick country for seeding
zName={'UK','USA'};
iz=1;
% pick policy combination
mlblS={'SD1Q1','SD2Q2','SD2Q2T2','SD2Q3T3'};
im=1;
% 3 cases: uncertainty for disease parameters (D), policy parameters (E),
% and joint (DE)
rlbl={'D','E','DE'};
nr=3;

% Solutions for fixed parameters
str_tmp = [matdir 'AltPol_', zName{iz} ];
load(str_tmp,'tt','ss','pp','xx','xxK','xlblS','xlblL','mlbl','ee');
% pick the one for your chosen policy combination
j=1;while strcmp(mlbl{j},mlblS{im})==0;j=j+1; end
    
tt0=tt{j};
pp0=pp{j};
xx0=xx{j};
ww0=tt0*52;

% load simulation results
xxx_draws=cell(nr,1);
for ir=1:nr
    fname = [matdir sprintf('%s_%s_Sim%s_Compressed',zName{iz},mlblS{im},rlbl{ir})];
    load(fname,'tt','xx_draws','xlblS','xlblL','pL','ssw');
    xxx_draws{ir}=xx_draws;
end
ww=tt*52;

nx=length(xlblS);
%% Plot variables for each case, population shares in percent
lsty0={'r--','b--','k--','m--','g--','c--'};
lsty1={'r-','b-','k-','m-','g-','c-'};

sc=100;
slbl={'Fixed Par','Mean','Median','66 prctl','33 prctl'};
xslct=[ 8 10 ];
for ir=1:nr
    xx_draws=xxx_draws{ir};
    nfig=(ir-1)*100;
    for ix=1:nx
        nfig=nfig+1;
        fig=figure(nfig);clf;hold on;
        % Fixed parameter path 
        y=sc*xx0(:,ix);
        plot(ww0,y,'-k','LineWidth',3);   
        % Random draws from parameters
        % Mean
        y=mean(sc*xx_draws(:,ix,:),3);
        plot(ww,y,'-r','LineWidth',3);
        % Median
        y=median(sc*xx_draws(:,ix,:),3);
        plot(ww,y,'-b','LineWidth',3);
        % bottom 1/6th 
        y=prctile(sc*xx_draws(:,ix,:),1/6*100,3);
        plot(ww,y,'--g','LineWidth',2);  
        % bottom 1/3rd
        y=prctile(sc*xx_draws(:,ix,:),1/3*100,3);
        plot(ww,y,'--m','LineWidth',2);
        % bottom 2/3rd
        y=prctile(sc*xx_draws(:,ix,:),2/3*100,3);
        plot(ww,y,'--m','LineWidth',2);
        % bottom 5/6th 
        y=prctile(sc*xx_draws(:,ix,:),5/6*100,3);
        plot(ww,y,'--g','LineWidth',2);
        shade(ssw(1),ssw(2),'y');
        shade(ssw(2),ssw(3),'g');
        grid on
        title([ xlblL{ix} ', Share of Population']);
        legend(slbl);
        xlim([ww(1) ww(end)]);
        yl=ylim;
        ylim([0 yl(2)]);
        xlabel('Weeks');
        ylabel('Percent');
        if sum(ix==xslct)>0
            figname=[figdir sprintf('GSEIR_%s_%s_ShareSim%s_%s',zName{iz},mlblS{im},rlbl{ir},xlblS{ix})];
            orient(fig,'landscape')
            print(fig,figname,'-dpdf','-bestfit');
        end
    end
end

