%% GSEIRbasepar: baseline parameterization for comparative statics 
% Parameterization of disease and policy parameters, includes seeding the
% infection 
% Time paths proceed in nS phases. The parameters below are defined as
% constant over all phases. The interventions change the values of some
% parameters
% A.Hornstein 4/3/2020
% removed erlative testing efficiency for tracing
% -------------------------------------------------------------------------
%% Disease related parameters
% Default basic reproduction rate for COVID-19 is 2.4
%  Fauci et all 2.2 https://www.nejm.org/doi/full/10.1056/NEJMe2002387
%  IC 2.4 in [2.0, 2.6]
rho=2.4*ones(nS,1);
if ~isempty(R0opt)
    switch lower(R0opt)
        case 'high'
            % Sanche et al median of R0 is 5.7 with 95% CI [3.8,8.9]
            rho=5.7*ones(nS,1);
    end
end
% -------------------------------------------------------------------------
% Incubation period 5.1 days
TE=(5/365)*ones(nS,1);
p.phi=1./TE;
% Average time to recovery of hospitalized, not on ICU: 8 days
TcH1=(8/365)*ones(nS,1);
p.cH1=1./TcH1;
% Average time to recovery of hospitalized, on ICU: 16 days
TcH2=(16/365)*ones(nS,1);
p.cH2=1./TcH2;
% Average time to recovery for asymptomatic infected and non-hospitalized
% symptomatics: same as for non-ICU hospitalized  
p.cI1=p.cH1;
p.cI2=p.cH1;
% Case fatality probability for non-ICU: adjusted such that without any 
% intervention the cumulative fatalitiy share is 0.9 percent, that would be
% the overall population CFI 
fp=(1.75/100)*ones(nS,1);
p.d=(p.cI1).*fp./(1-fp);
% Transition rate from asymptomatic infected I1 to symptomatic infected I2
% 50 percent of infected never become symptomatic
pIR=0.5;
p.b=p.cI1*(1-pIR)/pIR;
Tb=1./p.b;
% 4.4 percent of newly symptomatic will be hospitalized
p.omg=0.044*ones(nS,1);
% 30 percent of hospitalized newly infected will require ICU
p.eta=0.3*ones(nS,1);
% 50 percent of those in ICU die 
fpH2=0.5;
p.dH2=(p.cH2).*fpH2./(1-fpH2);
% symptomatic infected are 50 percent more infectious
p.sig=1.5*ones(nS,1);
% Basic reproduction rate: rho=a*brr0
[brr0,~]=GSEIR_R0fun(p);
p.a=rho./brr0;
% General quarantine/social distancing SD
% split meeting rate into disease transmission rate, aD, and social
% interaction rate, aS. Normalize initial aS=1
p.aS=ones(nS,1);
p.aD=p.a;
%% Interventions
% e, Quarantine effectiveness: fraction of identified infected I2 that no
% longer meet susceptibles S, e in [0 1], with 1 being most effective
% no intervention
p.eI1= 0.00*ones(nS,1);
p.eI2=(1/3)*ones(nS,1);  % baseline 1/3 self isolation with no delay, IC has 2/3 with mean delay of 5 days
p.eH1= 0.95*ones(nS,1);
p.eH2= 0.95*ones(nS,1);
% Remember initial disease transmission rate, aD0.
p.aD0=p.aD(1); 
% tracking
p.eT =0.00*ones(nS,1);
% flow rate of testing 
p.fE=0.00*ones(nS,1);
%% parameter names in p structure used in differential equation and MC sim
pL={'phi','cI1','cI2','cH1','cH2','d','b','omg','eta','sig','aD','aS', ...
    'eI1','eI2','eH1','eH2','eT','fET'};

