function [xx_draws,pY_draws] = ...
    GSEIRdraws(p,pU,pL,pS,ss,tt,x0,n_draws_save,k_draws)
%GSEIRdraws Generate random draws on parameters and solve for timepaths
% p  structure with parameter values
% pU structure with uncertainty about parameter values: CoV for percentage
%    deviations
% pL parameter labels in p structure
% pS structure with set of selected random draws
% pR structure with full set of random draws
%
% A.Hornstein, 4/3/2020
% 5/4/2020: fixed definition of 'a'
% -------------------------------------------------------------------------
% save every k_draws for a total of n_draws_save
n_draws=n_draws_save*k_draws;

% tt: interpolate all ODE solutions on the same time grid 
nt=length(tt);
t01=[tt(1) tt(end)];
% Matrices for saving draws
nx=length(x0);
np=length(pL);
xx_draws = NaN*ones(nt,nx,n_draws_save);
pY_draws = NaN*ones(np,n_draws_save);

jj_draw=0;
kk_draw=0;
for idraw=1:n_draws
    % generate random draw for parameter vector p1
    [pR,pY]=GSEIRdrawP(p,pU,pL);
    % only use random draws for a subset of parameters
    pi=GSEIRdrawS(p,pR,pS);
    % calculate disease path for pi  
    [ti,xi]=ode45(@(t,x)GSEIRdfeq(t,x,pi,ss),t01,x0);
    xi = interp1(ti,xi,tt);
    % save draws
    kk_draw = kk_draw+1;
    if kk_draw == k_draws
        jj_draw = jj_draw+1;
        kk_draw = 0;
        xx_draws(:,:,jj_draw)=xi;
        pY_draws(:,jj_draw)=pY;
    end
end

end
%% Random draws of the parameters
function [pi,pYi]=GSEIRdrawP(p,pU,pL)
% p structure with parameter values
% pU structure with uncertainty about parameter values: CoV for percentage
%    deviations
% pL parameter labels in p structure
% -------------------------------------------------------------------------
np=length(pL);
pi=p;
pYi=NaN(np,1);
% expected value of gamma RV: large to minimize skewness
EX=5;
for i=1:np
    eval(['y =p.' pL{i} ';']);
    y =y(1);
    if y>0
        eval(['yu=pU.' pL{i} ';']);
        A=(EX/(yu*log(y)))^2;
        B=EX/A;
        X=gamrnd(A,B);
        Y=exp(X-EX);
        eval(['pi.' pL{i} '=Y*p.' pL{i} ';']);
    end
    pYi(i)=Y;
end
pi.a=pi.aS.*pi.aD;
end
%% Use random draws for a subset of parameters
function [pi,pYi]=GSEIRdrawS(p,pR,pS)
% p  structure with parameter values
% pR structure with full set of random draws
% pS structure with set of selected random draws
% -------------------------------------------------------------------------
np=length(pS);
pi=p;
for i=1:np
    eval(['pi.' pS{i} '=pR.' pS{i} ';']);
end
pi.a=pi.aS.*pi.aD;
end
