%% GSEIRseedUSA seeding the infections for US
% follows ImpColl: start Jan 1 and calculate infected pop at DATE based
% on cumulative deaths till DATE
% I(t)=I(0)*exp(s*t) and F'=c*I
%
% A.Hornstein, 4/3/2020
% 4/22/2020: added option for high R0 and updated first and second data
% point
% -------------------------------------------------------------------------
% match USA
popM=328.24; % Haver 3/27/2020, Actual for 2019, Projected for 2020 is higher
pop =popM*10^6;

% A0: unconditional case fatality probablilty, pd0, and recovery time, Tc0 
pd0=0.009;
Tc0=14/365;
c0 =1/Tc0;
d0 =c0*pd0/(1-pd0);

% A1 Default: number of infections doubles in 5 days for R0=2.4, Ferguson et al 
s=log(2)/(5/365);
if ~isempty(R0opt)
    switch lower(R0opt)
        case 'high'
            % A1: number of infections doubles in 2.7 days for R0=5.7,
            % Sanche et al (2020)
            s=log(2)/(2.7/365);
    end
end

% % A1: growth rate is s=R0-gamma
% R0 =4.5;
% R0 =2.4;
% gam=d0+c0;
% s=(R0-1)*gam;

% A2: match cumulative fatalities on DATE (March 24th) when UK national lockdown
% was imposed. 

% US data: Cumulative deaths (D) and confirmed cases (C) downloaded from
% WHO, 4/22/2020
% https://covid19.who.int/region/euro/country/us
% March 24th: 673 D and 51,914 C
% April 14th: 21,972 D and 553,822 C (3 weeks later)
DAB=[673;21972];

% WHO data
% cumulative death counts on DATE, USA,
F1c=673; 
D01=(31+28+24)/365; % time from Jan 1
IC1=F1c*s/(d0*(1-exp(-s*D01))); % Infections at DATE
% total confirmed cases on DATE
IC1Act=51914; 

fprintf(fid,'\nSeeding the Infections, March 24, 2020 \n');
fprintf(fid,'Cumulative Deaths, $F_0$     & %7i \n',F1c);
fprintf(fid,'Identified Infections, $I_1(0)$ & %7i \n',IC1Act);
fprintf(fid,'Implied Infections, $I_1(0)+I_2(0)$   & %7i \n',round(IC1));
fprintf(fid,'Identification Rate, $Iact(0)/(I_1(0)+I_2(0)$ & %4.1f percent\n',100*IC1Act/IC1);

%% Hospital and ICU beds: Societ of Critical Care Medicine, March 15
% Source: https://www.aha.org/statistics/fast-facts-us-hospitals
HOSP=924107; % total hospital beds in US, 792,417 in community hospitals
ICU =55663+7419; % medical intensive + other ICU for adults
HOSP=HOSP-ICU;
ICUpop=ICU/pop;
HOSPpop=HOSP/pop;
%% Testing
% current testing rate is 100k/day
fc=(100*10^3)*365/pop;
